==> haskell-vty-6.2-72-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty
version:              6.2
visibility:           public
id:                   vty-6.2-5dKzRMimj0F1D1HuIfPTzr
key:                  vty-6.2-5dKzRMimj0F1D1HuIfPTzr
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use and to provide good support for common terminal types.

    See the @vty-examples@ package as well as the program
    @examples/interactive_terminal_test.hs@ included in the @vty@
    repository for examples on how to use the library.

    Import the @Graphics.Vty@ convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  f213f4b6d675df0f0fd0c4a20a82aa9c
exposed:              True
exposed-modules:
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Attributes.Color Graphics.Vty.Attributes.Color240
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Input Graphics.Vty.Input.Events Graphics.Vty.Output
    Graphics.Vty.Output.Mock Graphics.Vty.Picture
    Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Main
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

import-dirs:          /usr/lib/ghc-9.4.8/site-local/vty-6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/vty-6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/vty-6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty
hs-libraries:         HSvty-6.2-5dKzRMimj0F1D1HuIfPTzr
depends:
    base-4.17.2.1 binary-0.8.9.1
    blaze-builder-0.4.4.1-1AsqmJqbexUDW45IoYp4gz bytestring-0.11.5.3
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-mtl-0.2.1.0-LWyutRK1cqlCk2SYzoFhAy mtl-2.2.2
    parsec-3.1.16.1 stm-2.5.1.0 text-2.0.2
    utf8-string-1.0.2-D0oARDqSiCF3CIA0pPBIDm
    vector-0.13.2.0-DhQEcquLn8PDmAHUsOvAGS

haddock-interfaces:   /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vty-6.2-77-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-vty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vty
version:              6.2
visibility:           public
id:                   vty-6.2-24OTVSAh8AUKPMJVuGQjH5
key:                  vty-6.2-24OTVSAh8AUKPMJVuGQjH5
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use and to provide good support for common terminal types.

    See the @vty-examples@ package as well as the program
    @examples/interactive_terminal_test.hs@ included in the @vty@
    repository for examples on how to use the library.

    Import the @Graphics.Vty@ convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  379639afe4c55890097f28ba953e8849
exposed:              True
exposed-modules:
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Attributes.Color Graphics.Vty.Attributes.Color240
    Graphics.Vty.Config Graphics.Vty.Debug
    Graphics.Vty.DisplayAttributes Graphics.Vty.Error
    Graphics.Vty.Image Graphics.Vty.Image.Internal Graphics.Vty.Inline
    Graphics.Vty.Input Graphics.Vty.Input.Events Graphics.Vty.Output
    Graphics.Vty.Output.Mock Graphics.Vty.Picture
    Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Main
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/vty-6.2
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/vty-6.2
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/vty-6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vty
hs-libraries:         HSvty-6.2-24OTVSAh8AUKPMJVuGQjH5
depends:
    base-4.18.3.0 binary-0.8.9.1
    blaze-builder-0.4.4.1-3S17E8wm5XE4Chq6ULhvf8 bytestring-0.11.5.4
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.301.0
    microlens-0.4.14.0-4ENPj0tHNR0GzcdT8Xo5Q8
    microlens-mtl-0.2.1.0-BPqflcywilRLKDKsRXDgDa mtl-2.3.1
    parsec-3.1.16.1 stm-2.5.1.0 text-2.0.2
    utf8-string-1.0.2-shiuprzUpU7bW4pJ3bW0
    vector-0.13.2.0-BINMV7y6ibUKgFTnLXEi1A

haddock-interfaces:   /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
